<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :bottomOffset="250"
        :ajaxFun="ajaxFun"
        :paramObj="paramObj"
        ref="scrapMainScrapDetailTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="scrapDetail"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import TableForm from './scrapdetail-form'
import ttable from '@/views/common/ztt-table.vue'
import { mapGetters } from 'vuex'
import {
  fetchScrapDetailList,
  delScrapDetailObj
} from '../../../api/warehouse/scrapmain'

export default {
  props: {
    scrapMainId: {
      type: Number,
      default: 0
    },
    visible: {
      type: Boolean,
      default: false
    },
    scrapNo: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      ajaxFun: fetchScrapDetailList,
      paramObj: {},
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 盘点编号
          {
            minWidth: '140',
            prop: 'scrapNo',
            label: '报废单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 零件
          {
            minWidth: '120',
            prop: 'partNo',
            label: '零件',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件批号
          {
            minWidth: '200',
            prop: 'partBatchNo',
            label: '零件批号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件批号
          {
            minWidth: '200',
            prop: 'systemNo',
            label: '系统编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件序列号
          {
            minWidth: '140',
            prop: 'partSn',
            label: '零件序列号',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 仓库
          {
            minWidth: '120',
            prop: 'warehouseName',
            label: '仓库',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 库位
          {
            minWidth: '140',
            prop: 'locationName',
            label: '库位',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 库存数量
          {
            minWidth: '120',
            prop: 'locQty',
            label: '库存数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 报废数量
          {
            minWidth: '120',
            prop: 'scrapQty',
            label: '报废数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 报废人
          {
            minWidth: '120',
            prop: 'scrapUser',
            label: '报废人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 盘点编号
          {
            minWidth: '140',
            prop: 'status',
            label: '状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 报废时间
          {
            minWidth: '120',
            width: '200px',
            prop: 'scrapTime',
            label: '报废时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle,
            show: {
              val: ['未下发'],
              key: 'status'
            }
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 200,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    ttable,
    TableForm
  },
  watch: {
    visible: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.paramObj = { scrapMainId: this.scrapMainId }
          this.$nextTick(() => {
            this.getData()
          })
        }
      },
      immediate: true
    }
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      if (this.$refs.scrapMainScrapDetailTable !== undefined) {
        this.$refs.scrapMainScrapDetailTable.getDataList()
      }
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      if (!this.scrapMainId) {
        this.$message.error('请先保存')
        return
      }
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.scrapDetail.init(
          row == null ? null : row.id,
          this.scrapMainId,
          this.scrapNo
        )
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除ID为' + row.id, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(function() {
          return delScrapDetailObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    }
  }
}
</script>
